@@ -294,6 +294,7 @@ class Client(Buildin):
             code: str,
             scope: Optional[str] = None,
             timeout: Optional[int] = None,
+            skip_strip_code: bool = False,
             **kwargs: Any
     ) -> asyncio.Future:
         """Query ThingsDB.
@@ -311,6 +312,10 @@ class Client(Buildin):
                 Raise a time-out exception if no response is received within X
                 seconds. If no time-out is given, the client will wait forever.
                 Defaults to `None`.
+            skip_strip_code (bool, optional):
+                This can be set to True which can be helpful when line numbers
+                in syntax errors need to match. When False, the code will be
+                stripped from white-space and comments to reduce the code size.
             **kwargs (any, optional):
                 Can be used to inject variable into the ThingsDB code.
 
@@ -337,7 +342,9 @@ class Client(Buildin):
         if scope is None:
             scope = self._scope
 
-        code = strip_code(code)
+        if skip_strip_code is False:
+            code = strip_code(code)
+
         data = [scope, code]
         if kwargs:
             data.append(kwargs)
